@@ -10,7 +10,11 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { V1alpha2DevWorkspace, V222DevfileComponents } from '@devfile/api';
+import {
+  V1alpha2DevWorkspace,
+  V222Devfile,
+  V222DevfileComponents,
+} from '@devfile/api';
 import { CoreV1EventList, V1PodList } from '@kubernetes/client-node';
 import * as webSocket from './webSocket';
 
@@ -156,6 +160,8 @@ export interface IDevWorkspacePreferences {
   [key: string]: string | string[];
 }
 
+export type IEditors = Array<V222Devfile>;
+
 export type IEventList = CoreV1EventList;
 export type IPodList = V1PodList;
 
