@@ -15,6 +15,7 @@ import {
   IDevWorkspacePreferencesApi,
   IDevWorkspaceTemplateApi,
   IDockerConfigApi,
+  IEditorsApi,
   IEventApi,
   IGettingStartedSampleApi,
   IGitConfigApi,
@@ -72,4 +73,8 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
   get devWorkspacePreferencesApi(): IDevWorkspacePreferencesApi {
     throw new Error('Method not implemented.');
   }
+
+  get editorsApi(): IEditorsApi {
+    throw new Error('Method not implemented.');
+  }
 }
