@@ -15,6 +15,7 @@ import {
   V1alpha2DevWorkspaceTemplate,
   V222DevfileComponents,
 } from '@devfile/api';
+import { V222Devfile } from '@devfile/api';
 import { api } from '@eclipse-che/common';
 import * as k8s from '@kubernetes/client-node';
 import { IncomingHttpHeaders } from 'http';
@@ -427,6 +428,7 @@ export interface IDevWorkspaceClient {
   gettingStartedSampleApi: IGettingStartedSampleApi;
   sshKeysApi: IShhKeysApi;
   devWorkspacePreferencesApi: IDevWorkspacePreferencesApi;
+  editorsApi: IEditorsApi;
 }
 
 export interface IWatcherService<T = Record<string, unknown>> {
@@ -450,6 +452,20 @@ export interface IGettingStartedSampleApi {
   list(): Promise<Array<api.IGettingStartedSample>>;
 }
 
+export interface IEditorsApi {
+  /**
+   * Reads all Editors from ConfigMaps.
+   */
+  list(): Promise<Array<V222Devfile>>;
+
+  /**
+   * Returns an Editor from ConfigMap by its editorId.
+   * @param id editorId in the format of publisher/name/version
+   * @throws EditorNotFoundError if editor is not found
+   */
+  get(id: string): Promise<V222Devfile>;
+}
+
 export interface IShhKeysApi {
   list(namespace: string): Promise<Array<api.SshKey>>;
   add(namespace: string, sshKey: api.SshKey): Promise<api.SshKey>;
