@@ -25,7 +25,7 @@ describe('Factory Acceptance Redirect', () => {
     teardown(app);
   });
 
-  it('should redirect "/f?url=factoryUrl"', async () => {
+  it('should redirect to "/load-factory?url=factoryUrl" (no `factoryLink` param)', async () => {
     const factoryUrl = 'factoryUrl';
     const res = await app.inject({
       url: `/f?url=${factoryUrl}`,
@@ -34,20 +34,24 @@ describe('Factory Acceptance Redirect', () => {
     expect(res.headers.location).toEqual(`/dashboard/#/load-factory?url=${factoryUrl}`);
   });
 
-  it('should redirect "/f?factoryLink=url%3DfactoryUrl"', async () => {
+  it('should redirect to "/load-factory?url=factoryUrl"', async () => {
     const factoryUrl = 'factoryUrl';
     const res = await app.inject({
-      url: `/f?factoryLink=${encodeURIComponent('url=' + factoryUrl)}`,
+      url: `/f?factoryLink=${encodeURIComponent(btoa('url=' + factoryUrl))}`,
     });
     expect(res.statusCode).toEqual(302);
     expect(res.headers.location).toEqual(`/dashboard/#/load-factory?url=${factoryUrl}`);
   });
 
-  it('should redirect "/f?factoryLink=che-editor=che-incubator/.che-code/insiders&override.devfileFilename=my.devfile.yaml&url=factoryUr"', async () => {
+  it('should redirect to "/load-factory?che-editor=che-incubator%2F.che-code%2Finsiders&override.devfileFilename=my.devfile.yaml&url=factoryUrl"', async () => {
     const factoryUrl = 'factoryUrl';
     const res = await app.inject({
       url: `/f?${encodeURIComponent(
-        'factoryLink=che-editor=che-incubator/.che-code/insiders&override.devfileFilename=my.devfile.yaml&url=factoryUrl',
+        `factoryLink=${encodeURIComponent(
+          btoa(
+            'che-editor=che-incubator/.che-code/insiders&override.devfileFilename=my.devfile.yaml&url=factoryUrl',
+          ),
+        )}`,
       )}`,
     });
     expect(res.statusCode).toEqual(302);
@@ -56,28 +60,21 @@ describe('Factory Acceptance Redirect', () => {
     );
   });
 
-  it('should redirect "/f?url=factoryUrl"', async () => {
+  it('should redirect to "/load-factory?url=factoryUrl" (with extra encoding)', async () => {
     const factoryUrl = 'factoryUrl';
     const res = await app.inject({
-      url: `/f?url=${factoryUrl}`,
+      url: `/f?factoryLink%3D${encodeURIComponent(btoa('url=' + factoryUrl))}`,
     });
     expect(res.statusCode).toEqual(302);
     expect(res.headers.location).toEqual(`/dashboard/#/load-factory?url=${factoryUrl}`);
   });
 
-  it('should redirect "/f?factoryLink%3Durl%3DfactoryUrl"', async () => {
+  it('should redirect to "/load-factory?url=factoryUrl&error_code=access_denied" (with extra encoding)', async () => {
     const factoryUrl = 'factoryUrl';
     const res = await app.inject({
-      url: `/f?factoryLink%3Durl%3D${factoryUrl}`,
-    });
-    expect(res.statusCode).toEqual(302);
-    expect(res.headers.location).toEqual(`/dashboard/#/load-factory?url=${factoryUrl}`);
-  });
-
-  it('should redirect "/f?factoryLink%3Durl%3DfactoryUrl%26error_code%3Daccess_denied"', async () => {
-    const factoryUrl = 'factoryUrl';
-    const res = await app.inject({
-      url: `/f?factoryLink%3Durl%3D${factoryUrl}%26error_code%3Daccess_denied`,
+      url: `/f?factoryLink%3D${encodeURIComponent(
+        btoa('url=' + factoryUrl + '&error_code=access_denied'),
+      )}`,
     });
     expect(res.statusCode).toEqual(302);
     expect(res.headers.location).toEqual(
@@ -85,9 +82,11 @@ describe('Factory Acceptance Redirect', () => {
     );
   });
 
-  it('should redirect "/f?factoryLink=url%3Dhttps%253A%252F%252Fgithub.com%252Folexii4%252Fhelloworld.git"', async () => {
+  it('should redirect to "/load-factory?url=https%3A%2F%2Fgithub.com%2Folexii4%2Fhelloworld.git"', async () => {
     const res = await app.inject({
-      url: `/f?factoryLink=url%3Dhttps%253A%252F%252Fgithub.com%252Folexii4%252Fhelloworld.git`,
+      url: `/f?factoryLink=${encodeURIComponent(
+        btoa('url=https%3A%2F%2Fgithub.com%2Folexii4%2Fhelloworld.git'),
+      )}`,
     });
     expect(res.statusCode).toEqual(302);
     expect(res.headers.location).toEqual(
@@ -95,9 +94,13 @@ describe('Factory Acceptance Redirect', () => {
     );
   });
 
-  it('should redirect "/f?factoryLink=override.devfileFilename%3Ddevfile2.yaml%26url%3Dhttps%253A%252F%252Fgithub.com%252Folexii4%252Fhelloworld.git"', async () => {
+  it('should redirect to "/load-factory?override.devfileFilename=devfile2.yaml&url=https%3A%2F%2Fgithub.com%2Folexii4%2Fhelloworld.git"', async () => {
     const res = await app.inject({
-      url: `/f?factoryLink=override.devfileFilename%3Ddevfile2.yaml%26url%3Dhttps%253A%252F%252Fgithub.com%252Folexii4%252Fhelloworld.git`,
+      url: `/f?factoryLink=${encodeURIComponent(
+        btoa(
+          'override.devfileFilename=devfile2.yaml&url=https%3A%2F%2Fgithub.com%2Folexii4%2Fhelloworld.git',
+        ),
+      )}`,
     });
     expect(res.statusCode).toEqual(302);
     expect(res.headers.location).toEqual(
