@@ -22,8 +22,8 @@ import { lazyInject } from '@/inversify.config';
 import { ErrorBoundary } from '@/Layout/ErrorBoundary';
 import { ErrorReporter } from '@/Layout/ErrorReporter';
 import { IssueComponent } from '@/Layout/ErrorReporter/Issue';
-import Header from '@/Layout/Header';
-import Sidebar from '@/Layout/Sidebar';
+import { Header } from '@/Layout/Header';
+import { Sidebar } from '@/Layout/Sidebar';
 import StoreErrorsAlert from '@/Layout/StoreErrorsAlert';
 import { ROUTE } from '@/Routes/routes';
 import { AppAlerts } from '@/services/alerts/appAlerts';
