@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -28,8 +28,8 @@ import getComponentRenderer from '@/services/__mocks__/getComponentRenderer';
 
 import StartingStepWorkspaceConditions from '..';
 
-jest.mock('../../../TimeLimit');
-jest.mock('../../../StepTitle');
+jest.mock('@/components/WorkspaceProgress/TimeLimit');
+jest.mock('@/components/WorkspaceProgress/StepTitle');
 
 const mockOnNextStep = jest.fn();
 const mockOnRestart = jest.fn();
