@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2023 Red Hat, Inc.
+ * Copyright (c) 2018-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -32,6 +32,15 @@ describe('test buildFactoryLoaderPath()', () => {
       );
     });
 
+    test('editor-image parameter', () => {
+      const result = buildFactoryLoaderPath(
+        'git@github.com:eclipse-che/che-dashboard.git?editor-image=quay.io/mloriedo/che-code:copilot-builtin',
+      );
+      expect(result).toEqual(
+        '/f?editor-image=quay.io%2Fmloriedo%2Fche-code%3Acopilot-builtin&url=git%40github.com%3Aeclipse-che%2Fche-dashboard.git',
+      );
+    });
+
     test('devfilePath parameter', () => {
       const result = buildFactoryLoaderPath(
         'git@github.com:eclipse-che/che-dashboard.git?devfilePath=devfilev2.yaml',
@@ -149,7 +158,7 @@ describe('test storePathnameIfNeeded()', () => {
 
   test('regular path', () => {
     storePathIfNeeded('/test');
-    expect(mockUpdate).toBeCalledWith(SessionStorageKey.ORIGINAL_LOCATION_PATH, '/test');
+    expect(mockUpdate).toHaveBeenCalledWith(SessionStorageKey.ORIGINAL_LOCATION_PATH, '/test');
   });
 
   test('empty path', () => {
