@@ -34,7 +34,7 @@ describe('Get Devfile by URL', () => {
     jest.clearAllMocks();
   });
 
-  it('Should throw the "plugin registry URL is required" error message', async () => {
+  it('Should throw the "failed to fetch editor yaml" error message', async () => {
     const store = new FakeStoreBuilder().build();
 
     let errorText: string | undefined;
@@ -44,50 +44,35 @@ describe('Get Devfile by URL', () => {
       errorText = common.helpers.errors.getMessage(e);
     }
 
-    expect(errorText).toEqual('Plugin registry URL is required.');
-  });
-
-  it('Should throw the "failed to fetch editor yaml" error message', async () => {
-    const store = new FakeStoreBuilder().build();
-
-    let errorText: string | undefined;
-    try {
-      await getEditor(
-        'che-incubator/che-idea/next',
-        store.dispatch,
-        store.getState,
-        'https://dummy/che-plugin-registry/main/v3',
-      );
-    } catch (e) {
-      errorText = common.helpers.errors.getMessage(e);
-    }
-
-    expect(errorText).toEqual(
-      'Failed to fetch editor yaml by URL: https://dummy/che-plugin-registry/main/v3/plugins/che-incubator/che-idea/next/devfile.yaml.',
-    );
+    expect(errorText).toEqual('Failed to fetch editor yaml by id: che-incubator/che-idea/next.');
   });
 
   it('Should request a devfile content by editor id', async () => {
-    const store = new FakeStoreBuilder().build();
+    const editors = [
+      {
+        schemaVersion: '2.2.2',
+        metadata: {
+          name: 'che-idea',
+          attributes: {
+            publisher: 'che-incubator',
+            version: 'next',
+          },
+        },
+      } as devfileApi.Devfile,
+    ];
+    const store = new FakeStoreBuilder()
+      .withDwPlugins({}, {}, false, editors, 'che-incubator/che-idea/next')
+      .build();
 
     try {
-      await getEditor(
-        'che-incubator/che-idea/next',
-        store.dispatch,
-        store.getState,
-        'https://dummy/che-plugin-registry/main/v3',
-      );
+      const result = await getEditor('che-incubator/che-idea/next', store.dispatch, store.getState);
+      expect(result).toEqual(dump(editors[0]));
     } catch (e) {
       // no-op
     }
-
-    expect(mockFetchData).toHaveBeenCalledTimes(1);
-    expect(mockFetchData).toHaveBeenCalledWith(
-      'https://dummy/che-plugin-registry/main/v3/plugins/che-incubator/che-idea/next/devfile.yaml',
-    );
   });
 
-  it('Should request a devfile content by editor path', async () => {
+  it('Should return an existing devfile content by editor id', async () => {
     const store = new FakeStoreBuilder().build();
 
     try {
@@ -106,32 +91,6 @@ describe('Get Devfile by URL', () => {
     );
   });
 
-  it('Should return an existing devfile content by editor id', async () => {
-    const store = new FakeStoreBuilder()
-      .withDevfileRegistries({
-        devfiles: {
-          ['https://dummy/che-plugin-registry/main/v3/plugins/che-incubator/che-idea/next/devfile.yaml']:
-            {
-              content: dump(editor),
-            },
-        },
-      })
-      .build();
-
-    const customEditor = await getEditor(
-      'che-incubator/che-idea/next',
-      store.dispatch,
-      store.getState,
-      'https://dummy/che-plugin-registry/main/v3',
-    );
-
-    expect(mockFetchData).toHaveBeenCalledTimes(0);
-    expect(customEditor.content).toEqual(dump(editor));
-    expect(customEditor.editorYamlUrl).toEqual(
-      'https://dummy/che-plugin-registry/main/v3/plugins/che-incubator/che-idea/next/devfile.yaml',
-    );
-  });
-
   it('Should return an existing devfile content by editor path', async () => {
     const store = new FakeStoreBuilder()
       .withDevfileRegistries({
